==> fastapi_j2s-0.0.2.tar.gz: fastapi_j2s-0.0.2/setup.py <==
from setuptools import setup
# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "fastapi_j2s_readme.md").read_text(encoding='utf-8')

setup(
    name = 'FastApi_J2S',         # How you named your package folder (MyLib)
    packages = ['FastApi_J2S'],   # Chose the same as "name"
    version = '0.0.2',      # Start with a small number and increase it with every change you make
    license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description = 'Control Fast Api With Dictionary',   # Give a short description about your library
    long_description=long_description,            # Give a long description about your library
    long_description_content_type='text/markdown',
    author = 'KIMIN',                   # Type in your name
    author_email = 'staykimin@gmail.com',      # Type in your E-Mail
    url = 'https://github.com/staykimin/Modul-Wrapper',   # Provide either the link to your github or to your website
    # download_url = 'https://github.com/staykimin/Modul-Wrapper/archive/Modul-Wrapper-0.1.tar.gz',    # I explain this later on
    project_urls={
        'Documentation': 'https://github.com/staykimin/Modul-Wrapper',
        'Funding': 'https://github.com/staykimin/Modul-Wrapper',
        'Say Thanks!': 'https://saweria.co/staykimin',
        'Source': 'https://github.com/staykimin/Modul-Wrapper',
        'Tracker': 'https://github.com/staykimin/Modul-Wrapper/issues',
    }, 
    keywords = ['Kimin', 'Modul-Wrapper', 'J2S', 'FastApi-J2S'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
		'Modul-Wrapper',
		'fastapi',
		'Jinja2',
		'uvicorn',
		'colorama'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Utilities',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ], 
)

==> fastapi_j2s-0.1.tar.gz: fastapi_j2s-0.1/setup.py <==
from distutils.core import setup
# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name = 'FastApi_J2S',         # How you named your package folder (MyLib)
    packages = ['FastApi_J2S'],   # Chose the same as "name"
    version = '0.1',      # Start with a small number and increase it with every change you make
    license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description = 'Fast Api With Dictionary',   # Give a short description about your library
    long_description=long_description,            # Give a long description about your library
    long_description_content_type='text/markdown',
    author = 'KIMIN',                   # Type in your name
    author_email = 'staykimin@gmail.com',      # Type in your E-Mail
    url = 'https://github.com/staykimin/MFastApi-J2S',   # Provide either the link to your github or to your website
    # download_url = 'https://github.com/staykimin/Modul-Wrapper/archive/Modul-Wrapper-0.1.tar.gz',    # I explain this later on
    project_urls={
        'Documentation': 'https://github.com/staykimin/FastApi-J2S',
        'Funding': 'https://github.com/staykimin/FastApi-J2S',
        'Say Thanks!': 'https://saweria.co/staykimin',
        'Source': 'https://github.com/staykimin/FastApi-J2S',
        'Tracker': 'https://github.com/staykimin/FastApi-J2S/issues',
    }, 
    keywords = ['Kimin', 'FastApi', 'FastApi-J2S', 'J2S'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
		"Modul-Wrapper",
		'Jinja2',
		'mysql-connector-python',
		'requests'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Utilities',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ], 
)
